# src.gros_client.common package

## Submodules

## src.gros_client.common.camera module

### *class* src.gros_client.common.camera.Camera(baseurl: str)

Bases: `object`

#### \_\_init_\_(baseurl: str)

#### video_stream_status*: bool* *= None*

## src.gros_client.common.system module

### *class* src.gros_client.common.system.System

Bases: `object`

#### *static* reboot()

#### *static* shutdown()

## Module contents
